package com.ether;

import com.ether.dao.ObservatoryDAO;
import com.ether.tapas.Observatory;
import com.ether.tapas.Request;
import com.ether.tapas.Tapas;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jdom.Attribute;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.output.Format;
import org.jdom.output.XMLOutputter;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.springframework.beans.factory.annotation.Required;
import org.springframework.transaction.annotation.Transactional;

import java.io.FileOutputStream;
import java.util.List;

/**
 * @author rboipsl
 * @date 2 mars 2012
 */
public class TapasServiceImpl
        extends BackofficeServiceImpl
        implements TapasService
{

    public void createXMLRequest( @NotNull final Tapas fTapas )
    {

        final String fichier = "/home_local/workspace/request1.xml";

        final Element tapas = new Element( "tapas" );
        final Element request = new Element( "request" );
        final Element preferences = new Element( "preferences" );
        final Element format = new Element( "format" );
        final Element rayleighExtinction = new Element( "rayleigh_extinction" );

        //On crée un nouveau Document JDOM basé sur la racine que l'on vient de créer
        final Document document = new Document( tapas );

        final Attribute id = new Attribute( "Id", fTapas.getId() );
        tapas.setAttribute( id );

        //a terme devient une boucle
        final List<Request> requests = fTapas.getRequests();

        for( final Request iRequest : requests )
        {
            final Attribute idR = new Attribute( "Id", iRequest.getId().toString() );
            request.setAttribute( idR );

            tapas.addContent( request );
            request.addContent( preferences );

            final Attribute validF = new Attribute( "valid", iRequest.getPreference().getFormat().getFirstValue() );
            format.setAttribute( validF );
            format.setText( iRequest.getPreference().getFormat().getSecondValue() );

            final Attribute validR = new Attribute( "valid", iRequest.getPreference().getRayleighExtinction().getFirstValue() );
            rayleighExtinction.setAttribute( validR );
            rayleighExtinction.setText( iRequest.getPreference().getRayleighExtinction().getSecondValue() );

        }

        createXMLFile( fichier, document );
    }

    public void createXMLFile( final String fichier, final Document document )
    {
        try
        {
            //On utilise ici un affichage classique avec getPrettyFormat()
            final XMLOutputter sortie = new XMLOutputter( Format.getPrettyFormat() );
            //Remarquez qu'il suffit simplement de créer une instance de FileOutputStream
            //avec en argument le nom du fichier pour effectuer la sérialisation.
            sortie.output( document, new FileOutputStream( fichier ) );
        }
        catch( java.io.IOException ignored )
        {
        }
    }

    // list tous observatoires
    @Nullable
    @Transactional(readOnly = true)
    public List<Observatory> getAllObservatories()
            throws ServiceException
    {
        try
        {
            return _observatoryDAO.getAllObservatories();
        }
        catch( PersistenceException e )
        {
            throw new ServiceException( ServiceException.ServiceCode.OBSERVATORY_NOT_FOUND, e );
        }
    }


    @Required
    public void setObservatoryDAO( final ObservatoryDAO observatoryDAO )
    {
        _observatoryDAO = observatoryDAO;
    }

    private static final Log LOGGER = LogFactory.getLog( TapasServiceImpl.class );

    private ObservatoryDAO _observatoryDAO;
}
